@@ -54,10 +54,10 @@ class Plugins:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/plugins/{pluginID}', request.path_params)
+        url = utils.generate_url(operations.RunPluginRequest, base_url, '/v1/plugins/{pluginID}', request)
         
         headers = {}
-        query_params = utils.get_query_params(request.query_params)
+        query_params = utils.get_query_params(operations.RunPluginRequest, request)
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
         
         client = self._security_client
@@ -78,7 +78,7 @@ class Plugins:
 
         return res
 
-    def upsert_plugin(self, request: operations.UpsertPluginRequest) -> operations.UpsertPluginResponse:
+    def upsert_plugin(self, request: shared.Plugin) -> operations.UpsertPluginResponse:
         r"""Upsert a plugin
         """
         
@@ -87,7 +87,7 @@ class Plugins:
         url = base_url.removesuffix('/') + '/v1/plugins'
         
         headers = {}
-        req_content_type, data, form = utils.serialize_request_body(request)
+        req_content_type, data, form = utils.serialize_request_body(request, "request", 'json')
         if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
             headers['content-type'] = req_content_type
         if data is None and form is None:
